==> jcabi-xml-0.25.5-sources.jar: com/jcabi/xml/ConsoleErrorListener.java <==
/*
 * Copyright (c) 2012-2022, jcabi.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 1) Redistributions of source code must retain the above
 * copyright notice, this list of conditions and the following
 * disclaimer. 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution. 3) Neither the name of the jcabi.com nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.jcabi.xml;

import com.jcabi.log.Logger;
import java.util.Collection;
import java.util.concurrent.CopyOnWriteArrayList;
import javax.xml.transform.ErrorListener;
import javax.xml.transform.TransformerException;

/**
 * Error listener to console.
 *
 * @since 0.22
 */
final class ConsoleErrorListener implements ErrorListener {

    /**
     * Errors.
     */
    private final Collection<String> errors =
        new CopyOnWriteArrayList<>();

    @Override
    public void warning(final TransformerException warning) {
        Logger.warn(
            this, "#warning(): %s",
            warning.getMessageAndLocation()
        );
        this.errors.add(warning.getMessageAndLocation());
    }

    @Override
    public void error(final TransformerException error)
        throws TransformerException {
        Logger.error(
            this, "#error(): %s",
            error.getMessageAndLocation()
        );
        this.errors.add(error.getMessageAndLocation());
        throw error;
    }

    @Override
    public void fatalError(final TransformerException error)
        throws TransformerException {
        Logger.error(
            this, "#fatalError(): %s",
            error.getMessageAndLocation()
        );
        this.errors.add(error.getMessageAndLocation());
        throw error;
    }

    /**
     * Return all errors.
     * @return List of errors accumulated
     */
    public Collection<String> summary() {
        return this.errors;
    }

}

==> jcabi-xml-0.29.0-sources.jar: com/jcabi/xml/ConsoleErrorListener.java <==
/*
 * Copyright (c) 2012-2022, jcabi.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 1) Redistributions of source code must retain the above
 * copyright notice, this list of conditions and the following
 * disclaimer. 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution. 3) Neither the name of the jcabi.com nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.jcabi.xml;

import com.jcabi.log.Logger;
import java.util.Collection;
import java.util.Collections;
import java.util.concurrent.CopyOnWriteArrayList;
import javax.xml.transform.ErrorListener;
import javax.xml.transform.TransformerException;

/**
 * Error listener to console.
 *
 * @since 0.22
 */
final class ConsoleErrorListener implements ErrorListener {

    /**
     * Errors.
     */
    private final Collection<String> errors =
        new CopyOnWriteArrayList<>();

    @Override
    public void warning(final TransformerException warning) {
        Logger.warn(
            this, "#warning(): %s",
            warning.getMessageAndLocation()
        );
        this.errors.add(warning.getMessageAndLocation());
    }

    @Override
    public void error(final TransformerException error)
        throws TransformerException {
        Logger.error(
            this, "#error(): %s",
            error.getMessageAndLocation()
        );
        this.errors.add(error.getMessageAndLocation());
        throw error;
    }

    @Override
    public void fatalError(final TransformerException error)
        throws TransformerException {
        Logger.error(
            this, "#fatalError(): %s",
            error.getMessageAndLocation()
        );
        this.errors.add(error.getMessageAndLocation());
        throw error;
    }

    /**
     * Return all errors.
     * @return List of errors accumulated
     */
    public Collection<String> summary() {
        return Collections.unmodifiableCollection(this.errors);
    }

}
